.. _input-formats:

=============
Input formats
=============

ANDES currently supports the following input formats:

- ``.xlsx``: Excel spreadsheet file with ANDES data
- ``.raw`` and ``.dyr``: PSS/E RAW and DYR formats
- ``.m``: MATPOWER format
- ``.json``: JSON plain-text format with ANDES data

.. toctree::
   :maxdepth: 3

   xlsx
   psse
   matpower
   json
